package com.hssx.bms.controller;


import com.hssx.bms.entity.InstitutionalInformation;
import com.hssx.bms.entity.InstitutionalPic;
import com.hssx.bms.entity.SystemUser;
import com.hssx.bms.entity.vo.InstitutionalInformationVO;
import com.hssx.bms.service.InstitutionalInformationService;
import com.hssx.bms.service.InstitutionalPicService;
import com.hssx.bms.service.SystemUserService;
import com.hssx.bms.until.HttpRespMsg;
import com.hssx.bms.until.PageUtil;
import io.swagger.annotations.ApiOperation;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * @author 吴涛涛
 * @since 2019-10-15
 */
@Controller
@RequestMapping("/institutional")
public class InstitutionalInformationController {
    @Autowired
    private InstitutionalInformationService institutionalService;
    @Autowired
    private InstitutionalPicService institutionalPicService;

    /**
     * 教育机构账号的添加
     * 参数：account 账号 id 机构的id
     * @return
     */
    @ApiOperation(value = "教育机构账号的添加", notes = "教育机构账号的添加方法")
    @RequestMapping("/addAccount")
    @ResponseBody
    public HttpRespMsg addInstitutionalAccount(SystemUser systemUser){
        HttpRespMsg msg = institutionalService.addAccount(systemUser);
        return msg;
    }

    /**
     * 教育机构的的添加
     * 参数：name 名称，address 地址，lng 经度 lat 纬度 city:城市
     *      phone 电话,
     * @return
     */
    @ApiOperation(value = "教育机构的添加", notes = "教育机构的添加方法")
    @RequestMapping("/add")
    @ResponseBody
    public HttpRespMsg addInstitutionalInformation(InstitutionalInformationVO institutionalInformationVO){
        HttpRespMsg msg = institutionalService.add(institutionalInformationVO);
        return msg;
    }
    /**
     * 教育机构信息的修改
     * 参数：id 机构信息id，name 名称，address 地址，lng 经度 lat 纬度, headIntroduction 标签 （多个用的逗号隔开）
     *      phone 电话,amTime 上午上课时间,pmTime 下午上课时间， （file 上传的文件）非必传（简介图片）
     *      classAdvantages 课程特色，briefIntroduction 机构简介说明,file 简介图片文件,chargingStandard 收费标准
     * @return
     */
    @ApiOperation(value = "教育机构信息的修改", notes = "教育机构信息的修改")
    @RequestMapping("/update")
    @ResponseBody
    public HttpRespMsg updateInstitutionalInformation(InstitutionalInformation institutionalInformation,@RequestParam(required = false) MultipartFile file){
        HttpRespMsg msg = institutionalService.updateInstitutionalInformation(institutionalInformation,file);
        return msg;
    }
    /**
     * 教育机构信息的背景图片的修改
     * 参数：id 机构信息id，file 上传的文件数组
     * @return
     */
    @ApiOperation(value = "教育机构信息的背景图片的修改", notes = "教育机构信息的背景图片的修改")
    @RequestMapping("/updatePics")
    @ResponseBody
    public HttpRespMsg updateInstitutionPnteics(Integer id, @RequestParam(required = false) MultipartFile[] file){
        HttpRespMsg msg = institutionalPicService.institutionalPicService(id,file);
        return msg;
    }
    /**
     * 教育机构信息的背景图片的删除
     * 参数：id 要删除的背景图片id
     * @return
     */
    @ApiOperation(value = "教育机构信息的背景图片的删除", notes = "教育机构信息的背景图片的删除")
    @RequestMapping("/delete")
    @ResponseBody
    public HttpRespMsg deleteInstitutionPics(Integer id){
        HttpRespMsg msg = new HttpRespMsg();
        msg.data = institutionalPicService.removeById(id);
        return msg;
    }


    /**
     * 教育机构信息列表
     * 参数：pageNum 当前页码，pageSize 每页条数,keyName :关键字
     * @return
     */
    @ApiOperation(value = "教育机构信息列表", notes = "教育机构信息列表方法")
    @RequestMapping("/list")
    @ResponseBody
    public HttpRespMsg list(PageUtil page){
        HttpRespMsg msg = institutionalService.getInstitutionList(page);
        return msg;
    }

    /**
     * 创建机构账号获取机构列表
     * @return
     */
    @ApiOperation(value = "教育机构信息列表", notes = "教育机构信息列表方法")
    @RequestMapping("/createAccountforlist")
    @ResponseBody
    public HttpRespMsg createAccountforlist(){
        HttpRespMsg msg = institutionalService.createAccountforlist();
        return msg;
    }

    /**
     * 教育机构信息列表
     * 参数：id 机构id
     * @return
     */
    @ApiOperation(value = "教育机构信息详情", notes = "教育机构信息详情方法")
    @RequestMapping("/detail")
    @ResponseBody
    public HttpRespMsg detail(InstitutionalInformation information){
        HttpRespMsg msg = institutionalService.getInstitutionDetail(information);
        return msg;
    }

    /**
     * 教育机构信息的删除
     * 参数：id 机构id
     * @return
     */
    @ApiOperation(value = "教育机构信息删除", notes = "教育机构信息删除方法")
    @RequestMapping("/deleteInformation")
    @ResponseBody
    public HttpRespMsg delete(InstitutionalInformation information){
        HttpRespMsg msg = institutionalService.deleteById(information);
        return msg;
    }

    /**
     * 教育机构账号列表
     * 参数：pageNum 当前页码，pageSize 每页条数
     * @return
     */
    @ApiOperation(value = "教育机构账号列表", notes = "教育机构账号列表方法")
    @RequestMapping("/accountList")
    @ResponseBody
    public HttpRespMsg accountList(PageUtil page){
        HttpRespMsg msg = institutionalService.getInstitutionAccountList(page);
        return msg;
    }

    /**
     * 机构账号的删除
     * id:账号id
     * @return
     */
    @ApiOperation(value = "机构账号的删除", notes = "机构账号的删除方法")
    @RequestMapping("/delAccount")
    @ResponseBody
    public HttpRespMsg delAccount(SystemUser user){
        HttpRespMsg msg = institutionalService.delAccount(user);
        return msg;
    }


}

