package com.hssx.bms.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hssx.bms.entity.Book;
import com.hssx.bms.entity.BookCategory;
import com.hssx.bms.entity.BookPage;
import com.hssx.bms.entity.InstitutionalInformation;
import com.hssx.bms.entity.vo.BookVO;
import com.hssx.bms.mapper.BookCategoryMapper;
import com.hssx.bms.mapper.BookMapper;
import com.hssx.bms.mapper.BookPageMapper;
import com.hssx.bms.service.BookService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hssx.bms.until.HttpRespMsg;
import com.hssx.bms.until.PageUtil;
import com.hssx.bms.until.UploadFileToFileNameUtil;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;
import java.util.Comparator;
import java.util.List;
import java.util.UUID;
import java.util.stream.Collectors;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 吴涛涛
 * @since 2019-10-16
 */
@Service
public class BookServiceImpl extends ServiceImpl<BookMapper, Book> implements BookService {
    @Resource
    private BookMapper bookMapper;
    @Value("${upload.path}")
    private String path;
    @Resource
    private BookPageMapper bookPageMapper;
    @Resource
    private BookCategoryMapper bookCategoryMapper;

    @Override
    public HttpRespMsg addOrUpdateBook(Book book, MultipartFile file) {
        HttpRespMsg msg = new HttpRespMsg();
        String fileName = "";
        if (null != file) {
            fileName = UploadFileToFileNameUtil.uploadFile(file, path);
        }
        if (null != book.getId()) {
            //添加操作
            if (!"".equals(fileName)) {
                book.setCover(fileName);
            }
            bookMapper.insert(book);
        } else {
            //添加操作
            if (!"".equals(fileName)) {
                book.setCover(fileName);
            }
            bookMapper.insert(book);
        }
        msg.data = book;
        return msg;
    }

    @Override
    public HttpRespMsg getList(PageUtil page) {
        HttpRespMsg msg = new HttpRespMsg();
        if(null == page.getPageNum() && null == page.getPageSize()){
            page = new PageUtil();
        }
        QueryWrapper<Book> qw = new QueryWrapper<Book>();
        if(null != page.getKeyName() && !"".equals(page.getKeyName())){
            qw.like("name",page.getKeyName());
        }
        PageHelper.startPage(page.getPageNum(),page.getPageSize());
        List<Book> institutionalInformations = bookMapper.selectList(qw);
        PageInfo<Book> pageInfo = new PageInfo<>(institutionalInformations);
        msg.data = pageInfo;
        return msg;
    }

    @Override
    public HttpRespMsg del(String id) {
        HttpRespMsg msg = new HttpRespMsg();
        bookMapper.deleteById(id);
        bookPageMapper.delete(new QueryWrapper<BookPage>().eq("book_id",id));
        bookCategoryMapper.delete(new QueryWrapper<BookCategory>().eq("book_id",id));
        return msg;
    }

    @Override
    public HttpRespMsg getBookDetailById(String id) {
        HttpRespMsg msg = new HttpRespMsg();
        BookVO detail = bookMapper.selectDetailById(id);
        if(null != detail.getBookPages() && detail.getBookPages().size()>0){
            detail.setBookPages(detail.getBookPages().stream().sorted(Comparator.comparing(BookPage::getPageNum)).collect(Collectors.toList()));
        }
        if(null != detail.getCategories() && detail.getCategories().size()>0){
            detail.setCategories(detail.getCategories().stream().sorted(Comparator.comparing(BookCategory::getRank)).collect(Collectors.toList()));
        }
        msg.data = detail;
        return msg;
    }
}
