package com.hssx.bms.service.impl;

import ch.qos.logback.core.util.FileUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hssx.bms.entity.InstitutionalInformation;
import com.hssx.bms.entity.InstitutionalPic;
import com.hssx.bms.entity.SystemUser;
import com.hssx.bms.entity.UserAppointment;
import com.hssx.bms.entity.vo.InstitutionalInformationVO;
import com.hssx.bms.mapper.InstitutionalInformationMapper;
import com.hssx.bms.mapper.InstitutionalPicMapper;
import com.hssx.bms.mapper.SystemUserMapper;
import com.hssx.bms.service.InstitutionalInformationService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hssx.bms.until.HttpRespMsg;
import com.hssx.bms.until.MD5Util;
import com.hssx.bms.until.PageUtil;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.swing.*;
import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.UUID;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author 吴涛涛
 * @since 2019-10-15
 */
@Service
public class InstitutionalInformationServiceImpl extends ServiceImpl<InstitutionalInformationMapper, InstitutionalInformation> implements InstitutionalInformationService {
    @Resource
    private InstitutionalInformationMapper institutionalMapper;
    @Resource
    private SystemUserMapper systemUserMapper;
    @Resource
    private InstitutionalPicMapper picMapper;
    @Value("${upload.path}")
    private String path;
    @Override
    public HttpRespMsg add(InstitutionalInformationVO institutionalInformationVO) {
        HttpRespMsg msg = new HttpRespMsg();
        Integer count = institutionalMapper.selectCount(new QueryWrapper<InstitutionalInformation>().eq("name", institutionalInformationVO.getName()));
        if(count > 0){
            msg.setError("此机构已存在，请添加其他机构");
            return msg;
        }
        InstitutionalInformation information = new InstitutionalInformation();
        BeanUtils.copyProperties(institutionalInformationVO,information);
        institutionalMapper.insert(information);
        return msg;
    }

    @Override
    public HttpRespMsg updateInstitutionalInformation(InstitutionalInformation institutionalInformation,MultipartFile file) {
        HttpRespMsg msg = new HttpRespMsg();
        if (file != null) {
            File dir = null;
            dir = new File(path);
            // D://dolphin/upload 文件上传后所存储的位置,部署到服务器上时配置服务器地址即可
            if (!dir.exists()) {
                dir.mkdirs();
            }
            String fileName = "";
            if (file != null) {
                fileName = file.getOriginalFilename();
                System.out.println("上传文件名称" + file.getName() + "， dir = " + dir.getAbsolutePath());
                int pos = fileName.lastIndexOf(".");
                String rand = UUID.randomUUID().toString().replaceAll("-", "");
                String sufix = fileName.substring(pos);
                fileName = rand + sufix;
                institutionalInformation.setBriefIntroductionPic("/upload/"+fileName);
                File saveFile = new File(dir, fileName);
                try {
                    saveFile.createNewFile();
                    file.transferTo(saveFile);
                } catch (IOException e) {
                    e.printStackTrace();
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
        institutionalMapper.updateById(institutionalInformation);
        msg.data = institutionalInformation;
        return msg;
    }

    @Override
    public HttpRespMsg getInstitutionList(PageUtil page) {
        HttpRespMsg msg = new HttpRespMsg();
        if(null == page.getPageNum() && null == page.getPageSize()){
            page = new PageUtil();
        }
        QueryWrapper<InstitutionalInformation> qw = new QueryWrapper<InstitutionalInformation>();
        qw.eq("is_delete",0).select("id", "name", "phone", "address");
        PageHelper.startPage(page.getPageNum(),page.getPageSize());
        if(null != page.getKeyName() && !"".equals(page.getKeyName())){
            qw.like("name",page.getKeyName());
        }
        List<InstitutionalInformation> institutionalInformations = institutionalMapper.selectList(qw);
        PageInfo<InstitutionalInformation> pageInfo = new PageInfo<>(institutionalInformations);
        msg.data = pageInfo;
        return msg;
    }

    @Override
    public HttpRespMsg getInstitutionDetail(InstitutionalInformation information) {
        HttpRespMsg msg = new HttpRespMsg();
        InstitutionalInformationVO vo = institutionalMapper.selectDetailById(information.getId());
        msg.data = vo;
        return msg;
    }

    @Override
    public HttpRespMsg addAccount(SystemUser systemUser) {
        HttpRespMsg msg = new HttpRespMsg();
        InstitutionalInformation information = new InstitutionalInformation();
        InstitutionalInformation instution = institutionalMapper.selectById(systemUser.getId());
        information.setId(systemUser.getId());
        Integer count = systemUserMapper.selectCount(new QueryWrapper<SystemUser>().eq("account", systemUser.getAccount()));
        if(count > 0){
            msg.setError("账号已存在！");
            return msg;
        }
        systemUser.setPassword(MD5Util.getPassword("000000"));
        systemUser.setRoleType(1);
        systemUser.setId(null);
        systemUser.setRoleName(instution.getName());
        systemUserMapper.insert(systemUser);
        information.setSysId(systemUser.getId());
        institutionalMapper.updateById(information);
        return msg;
    }

    @Override
    public HttpRespMsg deleteById(InstitutionalInformation information) {
        HttpRespMsg msg = new HttpRespMsg();
        //软删除
        information.setIsDelete(1);
        institutionalMapper.updateById(information);
        //删除上传的自介绍图片
        picMapper.delete(new QueryWrapper<InstitutionalPic>().eq("information_id",information.getId()));
        InstitutionalInformation oldinformation = institutionalMapper.selectById(information.getId());
        if(null != oldinformation.getSysId()){
            //删除机构账号
            systemUserMapper.delete(new QueryWrapper<SystemUser>().eq("id",oldinformation.getSysId()));
        }
        return msg;
    }

    @Override
    public HttpRespMsg getInstitutionAccountList(PageUtil page) {
        HttpRespMsg msg = new HttpRespMsg();
        PageHelper.startPage(page.getPageNum(),page.getPageSize());
        List<SystemUser> list = systemUserMapper.selectList(new QueryWrapper<SystemUser>().eq("role_type", 1));
        PageInfo<SystemUser> pageInfo = new PageInfo<>(list);
        msg.data = pageInfo;
        return msg;
    }

    @Override
    public HttpRespMsg createAccountforlist() {
        HttpRespMsg msg = new HttpRespMsg();
        msg.data = institutionalMapper.selectList(new QueryWrapper<InstitutionalInformation>().isNull("sys_id"));
        return msg;
    }

    @Override
    public HttpRespMsg delAccount(SystemUser user) {
        HttpRespMsg msg = new HttpRespMsg();
        systemUserMapper.deleteById(user.getId());
        //删除机构绑定
        InstitutionalInformation information = institutionalMapper.selectOne(new QueryWrapper<InstitutionalInformation>().eq("sys_id", user.getId()));
        information.setSysId(null);
        institutionalMapper.updateById(information);
        return msg;
    }
}
