package com.hssx.bms.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hssx.bms.entity.InstitutionalInformation;
import com.hssx.bms.entity.SystemUser;
import com.hssx.bms.entity.UserAppointment;
import com.hssx.bms.entity.vo.UserAppointmentVO;
import com.hssx.bms.mapper.InstitutionalInformationMapper;
import com.hssx.bms.mapper.SystemUserMapper;
import com.hssx.bms.mapper.UserAppointmentMapper;
import com.hssx.bms.service.UserAppointmentService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hssx.bms.until.HttpRespMsg;
import com.hssx.bms.until.PageUtil;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author 吴涛涛
 * @since 2019-10-21
 */
@Service
public class UserAppointmentServiceImpl extends ServiceImpl<UserAppointmentMapper, UserAppointment> implements UserAppointmentService {
    @Resource
    private UserAppointmentMapper userAppointmentMapper;
    @Resource
    private SystemUserMapper systemUserMapper;
    @Resource
    private InstitutionalInformationMapper informationMapper;

    @Override
    public HttpRespMsg getList(SystemUser user,PageUtil page) {
        HttpRespMsg msg = new HttpRespMsg();
        SystemUser currentUser = systemUserMapper.selectById(user.getId());
        List<UserAppointment> list = new ArrayList<>();
        PageHelper.startPage(page.getPageNum(),page.getPageSize());
        if(0 == currentUser.getRoleType()){
            //管理员
            list = userAppointmentMapper.selectList(new QueryWrapper<UserAppointment>());
        }else{
            InstitutionalInformation information = informationMapper.selectOne(new QueryWrapper<InstitutionalInformation>().eq("sys_id", currentUser.getId()));
            list = userAppointmentMapper.selectList(new QueryWrapper<UserAppointment>().eq("org_id",information.getId()));
        }
        PageInfo<UserAppointment> pageInfo = new PageInfo<>(list);
        msg.data = pageInfo;
        return msg;
    }

    @Override
    public HttpRespMsg acceptAndUpdateDate(UserAppointmentVO userAppointmentVO) {
        HttpRespMsg msg = new HttpRespMsg();
        UserAppointment userAppointment = new UserAppointment();
        BeanUtils.copyProperties(userAppointmentVO,userAppointment);
        if(null != userAppointmentVO.getTimeDate()){
            LocalDate beginDateTime = LocalDate.parse(userAppointmentVO.getTimeDate(), DateTimeFormatter.ofPattern("yyyy-MM-dd"));
            userAppointment.setAppointDate(beginDateTime);
        }
        userAppointmentMapper.updateById(userAppointment);
        return msg;
    }

    @Override
    public HttpRespMsg getAppointmentList(SystemUser user, PageUtil page) {
        HttpRespMsg msg = new HttpRespMsg();
        PageHelper.startPage(page.getPageNum(),page.getPageSize());
        List<UserAppointmentVO> list = userAppointmentMapper.selectAppointmentList(user);
        PageInfo<UserAppointmentVO> pageInfo = new PageInfo<>(list);
        msg.data = pageInfo;
        return msg;
    }
}
